@@ -19,13 +19,13 @@ pub enum Error {
 	#[error("failed to do math on system times")]
 	SystemTime(#[from] std::time::SystemTimeError),
 	#[error("title ID {0} not found")]
-	NotFound(u64),
+	NotFound(u32),
 	#[error("cache failure")]
-	Cache(#[from] indexkv::Error)
+	Cache(#[from] indexkv::Error<u32>)
 }
 
-impl From<StreamError<Error>> for Error {
-	fn from(other: StreamError<Error>) -> Self {
+impl From<StreamError<Error, u32>> for Error {
+	fn from(other: StreamError<Error, u32>) -> Self {
 		match other {
 			StreamError::Internal(e) => Self::from(e),
 			StreamError::Caller(e) => e
